%global __requires_exclude typelib\\\(AppIndicator3\\\)

Name: virt-manager
Version: 1.4.1
Release: %mkrel 1
%global verrel %{version}-%{release}
Summary: Desktop tool for managing virtual machines via libvirt
Group: Graphical desktop/GNOME
License: GPLv2+
BuildArch: noarch
URL: http://virt-manager.org/
Source0: http://virt-manager.org/download/sources/%{name}/%{name}-%{version}.tar.gz

# Fix broken it/ko translations (bz #1433800)
Patch0001: 0001-Fix-broken-it-ko-translations-bz-1433800.patch

Patch0013: virt-manager-fix-full-screen-keys-menu.patch
Patch0014: virt-manager-1.3.2-mga4.patch


Requires: virt-manager-common = %{verrel}
Requires: python-gi
Requires: python-ipaddr
Requires: python-libvirt
Requires: typelib(Gtk) = 3.0
Requires: typelib(GtkVnc) = 2.0
Requires: typelib(SpiceClientGtk) = 3.0
Requires: python-requests
Requires: dbus-x11
# virt-manager works fine with either, so pull the latest bits so there's
# no ambiguity.
Requires: typelib(Vte) >= 2.90
# For console widget
Requires: spice-gtk
Requires: libvirt-utils
BuildRequires: intltool
# For python, and python2 rpm macros
BuildRequires: python2-devel

%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and LXC. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the backend
management API.

%package common
Summary: Common files used by the different Virtual Machine Manager interfaces
Group:    Emulators

# This version not strictly required: virt-manager should work with older,
# however varying amounts of functionality will not be enabled.
Requires: python-libvirt >= 0.7.0
Requires: libxml2-python
Requires: python-requests
Requires: python-ipaddr
Requires: libosinfo-common >= 0.2.10
# Required for gobject-introspection infrastructure
Requires: python-gi
Conflicts: virt-manager < 1.3.2-5

%description common
Common files used by the different virt-manager interfaces, as well as
virt-install related tools.


%package -n virt-install
Summary: Utilities for installing virtual machines
Group:    Emulators
Requires: virt-manager-common = %{verrel}
# For 'virsh console'
Requires: libvirt-client

Provides: virt-install
Provides: virt-clone
Provides: virt-convert
Provides: virt-xml
Obsoletes: python-virtinst
Conflicts: virt-manager < 1.3.2-5

%description -n virt-install
Package includes several command line utilities, including virt-install
(build and install new VMs) and virt-clone (clone an existing virtual
machine).


%prep
%setup -q

# Fix broken it/ko translations (bz #1433800)
%patch0001 -p1
%patch0013 -p1 -b .full-screen
%patch0014 -p1 -b .mageia-netinstall


%build
python setup.py configure \
	--libvirt-package-names="libvirt-utils" \
	--kvm-package-names="qemu-kvm" \
	--askpass-package-names="openssh-askpass" \
	--preferred-distros="mageia"
python setup.py build

%install
python setup.py \
    --no-update-icon-cache --no-compile-schemas \
    install -O1 --root=%{buildroot}
%find_lang %{name}

# Replace '#!/usr/bin/env python2' with '#!/usr/bin/python2'
# The format is ideal for upstream, but not a distro. See:
# https://fedoraproject.org/wiki/Features/SystemPythonExecutablesUseSystemPython
for f in $(find %{buildroot} -type f -executable -print); do
    sed -i "1 s|^#!/usr/bin/env python2|#!%{__python2}|" $f || :
done

# The conversion script was only added to virt-manager after several
# Fedora cycles of using gsettings. Installing it now could convert old data
# and wipe out recent settings.
rm %{buildroot}%{_datadir}/GConf/gsettings/org.virt-manager.virt-manager.convert


%files
%doc README.md COPYING NEWS.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_datadir}/%{name}/ui/*.ui
%{_datadir}/%{name}/virt-manager
%{_datadir}/%{name}/virtManager

%{_datadir}/%{name}/icons
%{_datadir}/icons/hicolor/*/apps/*

%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.virt-manager.virt-manager.gschema.xml

%files common -f %{name}.lang
%dir %{_datadir}/%{name}

%{_datadir}/%{name}/virtcli
%{_datadir}/%{name}/virtconv
%{_datadir}/%{name}/virtinst


%files -n virt-install
%{_mandir}/man1/virt-install.1*
%{_mandir}/man1/virt-clone.1*
%{_mandir}/man1/virt-convert.1*
%{_mandir}/man1/virt-xml.1*

%{_datadir}/%{name}/virt-install
%{_datadir}/%{name}/virt-clone
%{_datadir}/%{name}/virt-convert
%{_datadir}/%{name}/virt-xml

%{_bindir}/virt-install
%{_bindir}/virt-clone
%{_bindir}/virt-convert
%{_bindir}/virt-xml



%changelog
* Sun Mar 26 2017 tv <tv> 1.4.1-1.mga6
+ Revision: 1094870
- new release

* Thu Dec 22 2016 tv <tv> 1.4.0-4.mga6
+ Revision: 1076481
- Fix version check for spice GL support
- Don't return virtio1.0-net as a valid device name (rhbz#1399083)
- Fix window size tracking on wayland (rhbz#1375175)
- Fix 'resize to VM' on wayland (rhbz#1397598)
- Fix fedora24 installs from incorrectly using virtio-input (rhbz#1391522)
- Fix error checking extra_args for console argument

* Sun Jul 03 2016 cjw <cjw> 1.4.0-3.mga6
+ Revision: 1038561
- rediff patch to fix full-screen send-key menu behavior
- add a quick fix to allow mga4+ netinstalls

* Thu Jun 30 2016 tv <tv> 1.4.0-2.mga6
+ Revision: 1038183
- Fix italian translation from breaking the app (rhbz#1350185)

* Mon Jun 20 2016 tv <tv> 1.4.0-1.mga6
+ Revision: 1036878
- new release

* Mon May 23 2016 tv <tv> 1.3.2-9.20160520git2204de62d9.mga6
+ Revision: 1018107
- rebase to latest git: update viewer to work with spice GL
- fix conflicts for smooth upgrades

* Wed Apr 27 2016 neoclust <neoclust> 1.3.2-7.mga6
+ Revision: 1006866
- Add conflict to ease upgrade

* Tue Apr 26 2016 tv <tv> 1.3.2-6.mga6
+ Revision: 1006541
- wanted package is qemu-kvm instead of qemu

* Mon Apr 25 2016 tv <tv> 1.3.2-5.mga6
+ Revision: 1006127
- fix detecting Mageia when passing a remote URL:

* Thu Apr 21 2016 tv <tv> 1.3.2-4.mga6
+ Revision: 1004040
- do not use stable defaults
- kill old GConf conversion script
- split out virt-install pkg for non X11 servers

* Thu Apr 21 2016 tv <tv> 1.3.2-3.mga6
+ Revision: 1003985
- fix screenshot on cauldron/mga6 (rhbz#1297988)
- fix URL installs when content-length header missing (rhbz#1297900)

* Thu Apr 21 2016 tv <tv> 1.3.2-2.mga6
+ Revision: 1003979
- requires libvirt-utils

* Fri Mar 04 2016 oden <oden> 1.3.2-1.mga6
+ Revision: 985667
- 1.3.2

* Sun Jan 17 2016 wally <wally> 1.3.0-2.mga6
+ Revision: 925093
- rebuild to get more typelib() requires
- drop unneeded libgirepository-devel BR

* Sun Nov 29 2015 oden <oden> 1.3.0-1.mga6
+ Revision: 907046
- 1.3.0

* Mon Nov 16 2015 cjw <cjw> 1.2.1-2.mga6
+ Revision: 903660
- rediff patch1

* Tue Oct 27 2015 ycantin <ycantin> 1.2.1-1.mga6
+ Revision: 895779
- new version 1.2.1

* Sat Jun 20 2015 tv <tv> 1.2.0-1.mga6
+ Revision: 835801
- new release

* Wed Nov 19 2014 cjw <cjw> 1.1.0-7.mga5
+ Revision: 797801
- patch1: fix behavior of full screen send-key-combo menu

* Tue Oct 21 2014 oden <oden> 1.1.0-6.mga5
+ Revision: 792311
- fix deps

* Sun Oct 19 2014 cjw <cjw> 1.1.0-5.mga5
+ Revision: 791763
- rebuild to add missing typelib(LibvirtGLib) dependency

* Wed Oct 15 2014 umeabot <umeabot> 1.1.0-4.mga5
+ Revision: 739438
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 1.1.0-3.mga5
+ Revision: 737724
- rebuild in order to pick up typelib() deps

* Tue Sep 16 2014 umeabot <umeabot> 1.1.0-2.mga5
+ Revision: 690213
- Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes

  + ovitters <ovitters>
    - add gobject-introspection BR for typelib auto BR

* Mon Sep 08 2014 tv <tv> 1.1.0-1.mga5
+ Revision: 673705
- new release

* Fri Jun 06 2014 tv <tv> 1.0.1-3.mga5
+ Revision: 633908
- requires spice-gtk for spice-client-glib-usb-acl-helper (in order to be able to attach USB devices)

* Wed Jun 04 2014 fwang <fwang> 1.0.1-2.mga5
+ Revision: 632813
- rebuild for new vte

* Mon Mar 24 2014 oden <oden> 1.0.1-1.mga5
+ Revision: 607831
- 1.0.1

* Mon Feb 17 2014 oden <oden> 1.0.0-1.mga5
+ Revision: 593537
- 1.0.0

* Fri Jan 24 2014 oden <oden> 0.10.0-12.git1ffcc0cc.1.mga4
+ Revision: 567702
- sync with virt-manager-0.10.0-5.git1ffcc0cc.fc21.src.rpm

* Thu Nov 07 2013 oden <oden> 0.10.0-11.git79196cdf.1.mga4
+ Revision: 549880
- bump release
- sync with fedora, use git79196cdf that actually works
- drop the mbs patch, it's fixed upstream

* Sat Nov 02 2013 fwang <fwang> 0.10.0-10.mga4
+ Revision: 549033
- requires python-gi

* Mon Oct 21 2013 umeabot <umeabot> 0.10.0-9.mga4
+ Revision: 536982
- Mageia 4 Mass Rebuild

* Wed Sep 25 2013 oden <oden> 0.10.0-8.mga4
+ Revision: 486060
- P0: add the Mandriva mbs1 product

* Wed Jul 31 2013 wally <wally> 0.10.0-7.mga4
+ Revision: 461852
- rebuild with new rpm-mageia-setup to find typelib requires from python scripts without .py extension (mga#10863)

* Sun Jul 21 2013 fwang <fwang> 0.10.0-6.mga4
+ Revision: 456863
- python-virtinst merged into virt-manager

* Sun Jul 21 2013 fwang <fwang> 0.10.0-5.mga4
+ Revision: 456825
- fix typo

* Sun Jul 21 2013 fwang <fwang> 0.10.0-4.mga4
+ Revision: 456824
- add requires exception on indicator

* Sun Jul 21 2013 fwang <fwang> 0.10.0-3.mga4
+ Revision: 456817
- fix typo

* Sun Jul 21 2013 fwang <fwang> 0.10.0-2.mga4
+ Revision: 456816
- add some configure switches
- add some configure switches

* Sun Jul 21 2013 fwang <fwang> 0.10.0-1.mga4
+ Revision: 456810
- new version 0.10.0

* Mon Apr 15 2013 kharec <kharec> 0.9.5-2.mga3
+ Revision: 410148
- fix version in requires to fix #9740

* Fri Apr 12 2013 kharec <kharec> 0.9.5-1.mga3
+ Revision: 409803
- new version 0.9.5 (bugfixes)

* Mon Jan 14 2013 umeabot <umeabot> 0.9.4-4.mga3
+ Revision: 385422
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.9.4-3.mga3
+ Revision: 341559
- update file list

* Sun Dec 23 2012 cjw <cjw> 0.9.4-2.mga3
+ Revision: 334089
- add dependency on python-spice-client-gtk for spice display connections

* Thu Oct 18 2012 tv <tv> 0.9.4-1.mga3
+ Revision: 307932
- new release
- new release

* Mon Oct 15 2012 blino <blino> 0.9.3-2.mga3
+ Revision: 306479
- require acl for the getfacl command used in VirtualDisk.py

* Fri Jul 13 2012 tv <tv> 0.9.3-1.mga3
+ Revision: 270656
- new release

* Tue May 15 2012 ennael <ennael> 0.9.1-2.mga2
+ Revision: 235729
- add missing require gettext

* Fri Mar 02 2012 misc <misc> 0.9.1-1.mga2
+ Revision: 216639
- new version 0.9.1

  + fwang <fwang>
    - fix post script

  + tv <tv>
    - fix file list
    - new release

* Thu Apr 14 2011 tv <tv> 0.8.7-1.mga1
+ Revision: 84874
- new release

* Mon Mar 07 2011 saispo <saispo> 0.8.6-1.mga1
+ Revision: 66076
- imported package virt-manager

